@@ -11,7 +11,10 @@ Next steps:
 import csv
 import json
 import re
-import oclconstants
+
+import six
+
+from ocldev import oclconstants
 
 
 class OclCsvToJsonConverter(object):
@@ -103,8 +106,7 @@ class OclCsvToJsonConverter(object):
         """ Process CSV into OCL-formatted JSON """
         if method == OclCsvToJsonConverter.PROCESS_BY_ROW:
             return self.process_by_row(num_rows=num_rows, attr=attr)
-        else:
-            return self.process_by_definition(num_rows=num_rows, attr=attr)
+        return self.process_by_definition(num_rows=num_rows, attr=attr)
 
     def process_by_row(self, num_rows=0, attr=None):
         """ Process CSV by applying all definitions to each row before moving to the next row """
@@ -141,10 +143,10 @@ class OclCsvToJsonConverter(object):
                     self.DEF_KEY_IS_ACTIVE]:
                 continue
             if self.verbose:
-                print '\n%s' % ('*' * 120)
-                print 'Processing definition: %s' % csv_resource_def['definition_name']
+                six.print_(('\n%s' % ('*' * 120)))
+                six.print_(('Processing definition: %s' % csv_resource_def['definition_name']))
                 # print csv_resource_def
-                print '*' * 120
+                six.print_(('*' * 120))
             self._current_row_num = 0
             for csv_row in self.input_list:
                 if num_rows and self._current_row_num >= num_rows:
@@ -207,8 +209,7 @@ class OclCsvToJsonConverter(object):
                 if ocl_resource:
                     ocl_resources.append(ocl_resource)
             return ocl_resources
-        else:
-            return self.build_resource(csv_row, csv_resource_def, attr=attr)
+        return self.build_resource(csv_row, csv_resource_def, attr=attr)
 
     def is_skip_row(self, csv_resource_def, csv_row):
         """
@@ -384,10 +385,10 @@ class OclCsvToJsonConverter(object):
         # Optionally display debug info
         if self.verbose:
             if self._current_row_num:
-                print '[Row %s of %s] %s' % (self._current_row_num, self._total_rows,
-                                             json.dumps(ocl_resource))
+                six.print_(('[Row %s of %s] %s' % (self._current_row_num, self._total_rows,
+                                             json.dumps(ocl_resource))))
             else:
-                print json.dumps(ocl_resource)
+                six.print_((json.dumps(ocl_resource)))
 
         return ocl_resource
 
